==> 0.0.3.tar.gz: lib/typography/typography.dart <==
import 'dart:ui';

import 'package:flutter/material.dart';

import 'font_weight.dart';
import 'fonts.dart';
import 'letter_spacing.dart';
import 'line_height.dart';
import 'text_styles.dart';

class VitatTypography {
  static TextStyle create(
    TextStyles baseStyle, {
    Color color,
    Color backgroundColor,
    FontStyle fontStyle,
    double wordSpacing,
    TextBaseline textBaseline,
    Locale locale,
    Paint foreground,
    Paint background,
    List<Shadow> shadows,
    List<FontFeature> fontFeatures,
    TextDecoration decoration,
    Color decorationColor,
    TextDecorationStyle decorationStyle,
    double decorationThickness,
  }) {
    dynamic font;
    FontWeight fontWeight;
    double letterSpacing;
    double height;
    double fontSize;
    switch (baseStyle) {
      case TextStyles.titleHuge:
        font = Fonts.titleFont;
        fontSize = 32;
        fontWeight = StyledFontWeight.bold;
        height = LineHeight.medium;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.titleRegular:
        font = Fonts.titleFont;
        fontSize = 24;
        fontWeight = StyledFontWeight.bold;
        height = LineHeight.tiny;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.titleMedium:
        font = Fonts.titleFont;
        fontSize = 20;
        fontWeight = StyledFontWeight.bold;
        height = LineHeight.small;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.titleSmall:
        font = Fonts.titleFont;
        fontSize = 16;
        fontWeight = StyledFontWeight.bold;
        height = LineHeight.medium;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.titleTiny:
        font = Fonts.titleFont;
        fontSize = 14;
        fontWeight = StyledFontWeight.bold;
        height = LineHeight.small;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.paragraph:
        font = Fonts.textFont;
        fontSize = 16;
        fontWeight = StyledFontWeight.regular;
        height = LineHeight.medium;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.description:
        font = Fonts.textFont;
        fontSize = 14;
        fontWeight = StyledFontWeight.semibold;
        height = LineHeight.small;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.caption:
        font = Fonts.textFont;
        fontSize = 12;
        fontWeight = StyledFontWeight.bold;
        height = LineHeight.large;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.subtitle:
      default:
        font = Fonts.textFont;
        fontSize = 16;
        fontWeight = StyledFontWeight.semibold;
        height = LineHeight.medium;
        letterSpacing = LetterSpacing.regular;
        break;
    }
    return TextStyle(
      fontFamily: font,
      package: 'vitat_pulso',
      fontWeight: fontWeight,
      letterSpacing: letterSpacing,
      height: height,
      fontSize: fontSize,
      color: color,
      backgroundColor: backgroundColor,
      fontStyle: fontStyle,
      wordSpacing: wordSpacing,
      textBaseline: textBaseline,
      locale: locale,
      foreground: foreground,
      background: background,
      shadows: shadows,
      fontFeatures: fontFeatures,
      decoration: decoration,
      decorationColor: decorationColor,
      decorationStyle: decorationStyle,
      decorationThickness: decorationThickness,
    );
  }
}

==> 0.0.4.tar.gz: lib/typography/typography.dart <==
import 'dart:ui';

import 'package:flutter/material.dart';

import 'font_weight.dart';
import 'fonts.dart';
import 'letter_spacing.dart';
import 'line_height.dart';
import 'text_styles.dart';

class VitatTypography {
  static TextStyle create(
    TextStyles baseStyle, {
    Color color,
    Color backgroundColor,
    FontStyle fontStyle,
    double wordSpacing,
    TextBaseline textBaseline,
    Locale locale,
    Paint foreground,
    Paint background,
    List<Shadow> shadows,
    List<FontFeature> fontFeatures,
    TextDecoration decoration,
    Color decorationColor,
    TextDecorationStyle decorationStyle,
    double decorationThickness,
    FontWeight fontWeight,
  }) {
    dynamic font;
    FontWeight weight;
    double letterSpacing;
    double height;
    double fontSize;
    switch (baseStyle) {
      case TextStyles.titleHuge:
        font = Fonts.titleFont;
        fontSize = 32;
        weight = StyledFontWeight.bold;
        height = LineHeight.medium;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.titleRegular:
        font = Fonts.titleFont;
        fontSize = 24;
        weight = StyledFontWeight.bold;
        height = LineHeight.tiny;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.titleMedium:
        font = Fonts.titleFont;
        fontSize = 20;
        weight = StyledFontWeight.bold;
        height = LineHeight.small;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.titleSmall:
        font = Fonts.titleFont;
        fontSize = 16;
        weight = StyledFontWeight.bold;
        height = LineHeight.medium;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.titleTiny:
        font = Fonts.titleFont;
        fontSize = 14;
        weight = StyledFontWeight.bold;
        height = LineHeight.small;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.paragraph:
        font = Fonts.textFont;
        fontSize = 16;
        weight = StyledFontWeight.regular;
        height = LineHeight.medium;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.description:
        font = Fonts.textFont;
        fontSize = 14;
        weight = StyledFontWeight.semibold;
        height = LineHeight.small;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.caption:
        font = Fonts.textFont;
        fontSize = 12;
        weight = StyledFontWeight.bold;
        height = LineHeight.large;
        letterSpacing = LetterSpacing.regular;
        break;
      case TextStyles.subtitle:
      default:
        font = Fonts.textFont;
        fontSize = 16;
        weight = StyledFontWeight.semibold;
        height = LineHeight.medium;
        letterSpacing = LetterSpacing.regular;
        break;
    }

    return TextStyle(
      fontFamily: font,
      package: 'vitat_pulso',
      fontWeight: fontWeight ?? weight,
      letterSpacing: letterSpacing,
      height: height,
      fontSize: fontSize,
      color: color,
      backgroundColor: backgroundColor,
      fontStyle: fontStyle,
      wordSpacing: wordSpacing,
      textBaseline: textBaseline,
      locale: locale,
      foreground: foreground,
      background: background,
      shadows: shadows,
      fontFeatures: fontFeatures,
      decoration: decoration,
      decorationColor: decorationColor,
      decorationStyle: decorationStyle,
      decorationThickness: decorationThickness,
    );
  }
}
